@@ -205,6 +205,12 @@ formatting = {
         pyatspi.ROLE_NOTIFICATION: {
             'unfocused': 'roleName + unrelatedLabels'
             },
+        pyatspi.ROLE_PAGE: {
+            'focused': 'label + readOnly + currentLineText + anyTextSelection',
+            'unfocused': 'label + readOnly + currentLineText + anyTextSelection + ' + MNEMONIC,
+            'basicWhereAmI': 'label + readOnly + textRole + textContent + anyTextSelection + ' + MNEMONIC,
+            'detailedWhereAmI': 'label + readOnly + textRole + textContentWithAttributes + anyTextSelection + ' + MNEMONIC
+            },
         pyatspi.ROLE_PAGE_TAB: {
             'focused': 'labelAndName + roleName + positionInList + ' + MNEMONIC + ' + accelerator',
             'unfocused': 'labelAndName + roleName + positionInList + ' + MNEMONIC + ' + accelerator',
