@@ -132,6 +132,14 @@ class Script(Gecko.Script):
 
         Gecko.Script.doWhereAmI(self,inputEvent, basicOnly)
 
+    def useStructuralNavigationModel(self):
+        """Returns True if structural navigation should be enabled here."""
+
+        if self.isEditableMessage(orca_state.locusOfFocus):
+            return False
+
+        return Gecko.Script.useStructuralNavigationModel(self)
+
     def onFocusedChanged(self, event):
         """Callback for object:state-changed:focused accessibility events."""
 
@@ -144,8 +152,12 @@ class Script(Gecko.Script):
         obj = event.source
         if self.spellcheck.isAutoFocusEvent(event):
             orca.setLocusOfFocus(event, event.source, False)
+            self.updateBraille(orca_state.locusOfFocus)
 
-        if obj.parent == self.spellcheck.getSuggestionsList():
+        if self.spellcheck.isSuggestionsItem(event.source) \
+           and self.spellcheck.isSuggestionsItem(orca_state.locusOfFocus):
+            orca.setLocusOfFocus(event, event.source, False)
+            self.updateBraille(orca_state.locusOfFocus)
             self.spellcheck.presentSuggestionListItem()
             return
 
@@ -199,6 +211,11 @@ class Script(Gecko.Script):
         if event.source == self.spellcheck.getSuggestionsList():
             return
 
+        parent = event.source.parent
+        if parent and parent.getRole() == pyatspi.ROLE_COMBO_BOX \
+           and not parent.getState().contains(pyatspi.STATE_FOCUSED):
+            return
+
         Gecko.Script.onSelectionChanged(self, event)
 
     def onSensitiveChanged(self, event):
@@ -396,25 +413,16 @@ class Script(Gecko.Script):
     def isEditableMessage(self, obj):
         """Returns True if this is a editable message."""
 
-        # For now, look specifically to see if this object is the
-        # document frame. If it's not, we cannot be sure how complex
-        # this message is and should let the Gecko code kick in.
-        #
-        if obj \
-           and obj.getRole() == pyatspi.ROLE_DOCUMENT_FRAME \
-           and obj.getState().contains(pyatspi.STATE_EDITABLE):
-            return True
-
-        return False
-
-    def useCaretNavigationModel(self, keyboardEvent):
-        """Returns True if we should do our own caret navigation."""
-
-        if self.isEditableMessage(orca_state.locusOfFocus) \
-           or self.isNonHTMLEntry(orca_state.locusOfFocus):
+        if not obj:
             return False
 
-        return Gecko.Script.useCaretNavigationModel(self, keyboardEvent)
+        if not obj.getState().contains(pyatspi.STATE_EDITABLE):
+            return False
+
+        if self.isNonHTMLEntry(obj):
+            return False
+
+        return True
 
     def onWindowActivated(self, event):
         """Callback for window:activate accessibility events."""
@@ -425,6 +433,7 @@ class Script(Gecko.Script):
 
         self.spellcheck.presentErrorDetails()
         orca.setLocusOfFocus(None, self.spellcheck.getChangeToEntry(), False)
+        self.updateBraille(orca_state.locusOfFocus)
 
     def onWindowDeactivated(self, event):
         """Callback for window:deactivate accessibility events."""
