@@ -75,6 +75,20 @@ class Script(default.Script):
         self.updateBraille(obj)
         speech.speak(self.speechGenerator.generateSpeech(obj, alreadyFocused=True))
 
+    def onNameChanged(self, event):
+        """Callback for object:property-change:accessible-name events."""
+
+        role = event.source.getRole()
+        try:
+            focusRole = orca_state.locusOfFocus.getRole()
+        except:
+            focusRole = None
+
+        if role == pyatspi.ROLE_FRAME and focusRole == pyatspi.ROLE_TABLE_CELL:
+            return
+
+        default.Script.onNameChanged(self, event)
+
     def onFocus(self, event):
         """Callback for focus: accessibility events."""
 
@@ -106,6 +120,12 @@ class Script(default.Script):
             orca.setLocusOfFocus(event, event.source)
             return
 
+        # Unfiled. Happens in Evolution, but for what seems to be a generic
+        # Gtk+ toggle button. So we'll handle it here.
+        if role == pyatspi.ROLE_TOGGLE_BUTTON:
+            orca.setLocusOfFocus(event, event.source)
+            return
+
         # Unfiled. But this happens when you are in Gedit, get into a menu
         # and then press Escape. The text widget emits a focus: event, but
         # not a state-changed:focused event.
